CA27_Cl02.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Panoramic views |
clickAndWait | link=Añadir panoramic view |
type | id_name | Nuevo
type | id_external_url | www.nuevo.com
clickAndWait | _save |
type | searchbar | nuevo
click | //input[@value='Buscar'] |
click | action-toggle |
select | action | label=Eliminar panoramic views seleccionado/s
clickAndWait | index |
verifyTextPresent | exact:¿Está seguro? |
verifyTextPresent | exact:¿Está seguro de que quiere borrar los panoramic view seleccionados? Los siguientes objetos y sus elementos relacionados serán eliminados: |
verifyTextPresent | Panoramic view: Nuevo (http://www.nuevo.com/) |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |